@@ -5,6 +5,7 @@ from __future__ import absolute_import
 from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
 from bitmovin_api_sdk.common.poscheck import poscheck_except
 from bitmovin_api_sdk.encoding.simple.jobs.vod.vod_api import VodApi
+from bitmovin_api_sdk.encoding.simple.jobs.live.live_api import LiveApi
 
 
 class JobsApi(BaseApi):
@@ -25,3 +26,10 @@ class JobsApi(BaseApi):
             base_url=base_url,
             logger=logger
         )
+
+        self.live = LiveApi(
+            api_key=api_key,
+            tenant_org_id=tenant_org_id,
+            base_url=base_url,
+            logger=logger
+        )
